@@ -79,5 +79,6 @@ pub trait ValidatedMap {
 }
 pub fn split_once(s: &str, pattern: char) -> (&str, &str) {
     let index = s.find(pattern).unwrap_or_else(|| s.len());
-    s.split_at(index)
+    let (l, r) = s.split_at(index);
+    (l, if r.is_empty() { "" } else { &r[1..] })
 }
